---
title: <span class="badge object-type-scalar"></span> Milligram
---
# <span class="badge object-type-scalar"></span> Milligram

Mass: milligram (mg)

## Definition

```python
# Mass: milligram (mg)
Milligram: typing.Literal["massmg"] = "massmg"
```
